<?php
/*
 * Home Page Post Slider
 */

if(!class_exists('Smartblog_Post_Slider')){

	class Smartblog_Post_Slider extends WP_Widget{
		
		/**
		 * Sets up a new Post Slider widget instance.
		 */
	
		function __construct(){
			/* Constructor */
			$widget_ops = array('classname' => 'smartblog_post_slider', 'description' => esc_html__('Display images from a specific category. The widget works best in the Homepage Banner area.','smartblog'));
			parent::__construct('smartblog_post_slider', esc_html__('T &rarr; Post Slider','smartblog'), $widget_ops);
		}
		
		function widget($args, $instance){
			/* print the widget on front end */
			
			$category 	 = empty($instance['category']) ? '' : $instance['category'];
			$number 	 = empty($instance['number']) ? '' : $instance['number'];
			
			echo wp_kses( $args['before_widget'], wp_kses_allowed_html( 'post' ) );
			
			/* if any category is selected then get posts from that categories, otherwise get all posts */	
			if (!empty($category) ) {
					  $slider_args = array(
								'post_type' => 'post',
								'posts_per_page' => $number,
								'post_status' => 'publish',
								'tax_query' => array(
										array(
											'taxonomy' => 'category',
											'field' => 'slug',
											'terms' => $category,
										)
									)
					  );
			}
			else {
					$slider_args = array('post_type' => 'post',
							'post_status' => 'publish',
							'posts_per_page' => $number
						);
			}
			
			$post_query = null;
			$post_query = new WP_Query($slider_args);
			
			if ($post_query->have_posts()){
				echo '<div class="home-top-slider row">
						<div id="owl-header" class="owl-carousel">';
				while ($post_query->have_posts()) : $post_query->the_post();
				global $post;
						echo '<div class="item">
									<a href="'.esc_url(get_the_permalink()).'">';
									$category = get_the_category($post->ID);
									if ( has_post_thumbnail() ) {
										echo '<img src="'.esc_url(get_the_post_thumbnail_url($post->ID,"smartblog-slider-image")).'" /></a>';
									}
									else{
										echo '<img src="'.get_stylesheet_directory_uri().'/images/noimage.jpg" /></a>';
									}
									echo '<div class="post-info">
										<h3><a href="'.esc_url(get_the_permalink()).'">'.esc_html(get_the_title()).'</a></h3>
										<p class="cate">';
										if(!empty($category))
										{
											$count=count($category);
											$flag=1;
											foreach($category as $cat)
											{
												$span='<span class="hr">/</span>';
												if($flag==$count){ $span=''; }
												echo '<a href="'.esc_url(get_term_link($cat->term_id)).'">'.esc_html($cat->name).'</a>'.$span;
												$flag++;
											}
										}
										echo '</p>
									</div>
								</div>';
				endwhile;
				echo '</div>
						<div class="customNavigation">
							<a class="btn prev"><i class="fa fa-angle-double-left"></i></a>
							<a class="btn next"><i class="fa fa fa-angle-double-right"></i></a>
						</div>
					</div>';
			}
			
			echo wp_kses( $args['after_widget'], wp_kses_allowed_html( 'post' ) );
			/* Restore original Post Data */
			wp_reset_postdata();wp_reset_query();
		}
		
		/**
		 * Handles updating settings for the current Display Post widget instance.
		 */
		 
		function update($new_instance, $old_instance){
			/* save the widget */
			return $new_instance;
		}
		
		/**
		 * Outputs the Homepage post slider widget settings form.
		 * @param array $instance Current settings.
		 */
		function form($instance){
			
			$category 		= isset($instance['category']) ? $instance['category'] : '';
			$number 		= isset($instance['number']) ? $instance['number'] : '';
			
			
			?>
			<!-- carousel sldier taxonomy fetch as per post type field -->
			<p>
			  <label for="<?php echo $this->get_field_id('category'); ?>"><?php echo __('Categories:', 'smartblog'); ?></label>
			  <select id="<?php echo $this->get_field_id('category'); ?>" name="<?php echo $this->get_field_name('category'); ?>[]" class="<?php echo $this->get_field_id('category'); ?> widefat" multiple="multiple">
				<option value=""><?php echo esc_html__('Select Category', 'smartblog'); ?></option>
				<?php
				 $taxonomies = get_object_taxonomies((object) array('post_type' =>'post', 'public' => true, '_builtin' => true));
						$terms = get_terms($taxonomies[0], 'orderby=name&hide_empty=0');
						if(!empty($terms))
						{
							foreach ($terms as $term) {
								$term_value = $term->slug;
								$selected='';
								if(!empty($category))
								{
									$selected = (in_array($term_value, $category) || in_array($term->slug, $category)) ? "selected" : ''; 
								}?>
								<option value="<?php echo esc_html($term_value); ?>" <?php echo $selected ?>> <?php echo esc_attr($term->name); ?></option>
								<?php
							}
						}
				  ?>
			  </select>
			</p>
			
			<!-- post sldier number field -->
			<p>
			  <label for="<?php echo $this->get_field_id('number'); ?>"><?php echo __('Number of posts', 'smartblog'); ?>:
				<input class="widefat" id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="number" min="1" value="<?php echo intval($number); ?>" />
			  </label>
			</p>
			<?php			
		}
	}
}
/* Function to include owl css and js */ 

add_action( 'wp_enqueue_scripts', 'smartblog_slider_enqueue_scripts' );

if(!function_exists('smartblog_slider_enqueue_scripts')){
	function smartblog_slider_enqueue_scripts()
	{
		 wp_enqueue_script( 'slider', get_stylesheet_directory_uri() . '/js/owl.carousel.js', array(), '', true );
		 wp_enqueue_style( 'blogstyletheme-owl', get_template_directory_uri().'/css/owl.carousel.css' );
	}
}

add_action('wp_footer','smartblog_owl_slider_script');

if(!function_exists('smartblog_owl_slider_script')){

function smartblog_owl_slider_script()
{
	?>
	 <script>
		jQuery.noConflict();
		jQuery( document ).ready(function( $ ) {

      var owl1 = $("#owl-header");

      owl1.owlCarousel({
      items : 6, //10 items above 1000px browser width
      itemsDesktop : [2000,3], //5 items between 1000px and 901px
      itemsDesktopSmall : [900,2], // 3 items betweem 900px and 601px
      itemsTablet: [600,1], //2 items between 600 and 0;
      itemsMobile : false // itemsMobile disabled - inherit from itemsTablet option
      
      });
	  
	  // Custom Navigation Events
      jQuery(".next").click(function(){
        owl1.trigger('owl.next');
      })
      jQuery(".prev").click(function(){
        owl1.trigger('owl.prev');
      })
      jQuery(".play").click(function(){
        owl1.trigger('owl.play',1000);
      })
      jQuery(".stop").click(function(){
        owl1.trigger('owl.stop');
      })
	 });
    </script>
	<?php
}
}

/* EOF */
?>